package com.ruoyi.branch.service;

import java.util.List;
import com.ruoyi.branch.domain.TBranchAssess;

/**
 * 纪律考评Service接口
 * 
 * @author ruoyi
 * @date 2023-07-31
 */
public interface ITBranchAssessService 
{
    /**
     * 查询纪律考评
     * 
     * @param assessId 纪律考评主键
     * @return 纪律考评
     */
    public TBranchAssess selectTBranchAssessByAssessId(Long assessId);

    /**
     * 查询纪律考评列表
     * 
     * @param tBranchAssess 纪律考评
     * @return 纪律考评集合
     */
    public List<TBranchAssess> selectTBranchAssessList(TBranchAssess tBranchAssess);

    /**
     * 新增纪律考评
     * 
     * @param tBranchAssess 纪律考评
     * @return 结果
     */
    public int insertTBranchAssess(TBranchAssess tBranchAssess);

    /**
     * 修改纪律考评
     * 
     * @param tBranchAssess 纪律考评
     * @return 结果
     */
    public int updateTBranchAssess(TBranchAssess tBranchAssess);

    /**
     * 批量删除纪律考评
     * 
     * @param assessIds 需要删除的纪律考评主键集合
     * @return 结果
     */
    public int deleteTBranchAssessByAssessIds(Long[] assessIds);

    /**
     * 删除纪律考评信息
     * 
     * @param assessId 纪律考评主键
     * @return 结果
     */
    public int deleteTBranchAssessByAssessId(Long assessId);
}
